[{
  Name: 'Weather Widget - Soxfan1966 Version',
  Author: 'Jim Champoux',
  Version: '2020-05-08',
  // Note: 'Based on the Open Weather Widget by Generoso Martello, version 2013-03-31'

  GroupName: '',
  IconImage: 'pages/control/widgets/homegenie/environment/weather/images/partlycloudy.png',
  StatusText: '',
  Description: '',

  RenderView: function (cuid, module) {
    var container = $(cuid);
    var widget = container.find('[data-ui-field=widget]');

    if (!this.Initialized) {
      this.Initialized = true;
      // settings button
      widget.find('[data-ui-field=settings]').on('click', function () {
        HG.WebApp.ProgramEdit._CurrentProgram.Domain = module.Domain;
        HG.WebApp.ProgramEdit._CurrentProgram.Address = module.Address;
        HG.WebApp.ProgramsList.UpdateOptionsPopup();
      });
    }

    function precision(num, n)
     // round num to n significant digits
     {
       return num.toFixed(n)
     }

     function toTitleCase(str) {
        return str.replace(
            /\w\S*/g,
            function(txt) {
                return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
            }
        );
    }
    
    var display_location = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.DisplayLocation').Value;
    var serviceapi = HG.WebApp.Utility.GetModulePropertyByName(module, 'ConfigureOptions.ApiKey').Value;
    if (serviceapi == '' || serviceapi == '?') {
      widget.find('[data-ui-field=name]').html('Not configured');
      widget.find('[data-ui-field=sunrise_value]').html(sunrise);
      //
      widget.find('[data-ui-field=settings]').qtip({
        content: {
          title: HG.WebApp.Locales.GetLocaleString('control_widget_notconfigured_title'),
          text: HG.WebApp.Locales.GetLocaleString('control_widget_notconfigured_text'),
          button: HG.WebApp.Locales.GetLocaleString('control_widget_notconfigured_button')
        },
        show: { event: false, ready: true, delay: 3000 },
        events: {
          hide: function () {
            $(this).qtip('destroy');
          }
        },
        hide: { event: false, inactive: 3000 },
        style: { classes: 'qtip-red qtip-shadow qtip-rounded qtip-bootstrap' },
        position: { my: 'top center', at: 'bottom center' }
      });
    } else if (display_location == '') {
      widget.find('[data-ui-field=name]').html('Waiting for data...');
      widget.find('[data-ui-field=last_updated_value]').html('Not updated!');
    } else {
      widget.find('[data-ui-field=name]').html(display_location);
      //
      var windspeed = HG.WebApp.Utility.GetModulePropertyByName(module, 'Sensor.Wind.Speed').Value;
      windspeed=windspeed*0.6214;
      windspeed = Math.round(windspeed, 1);
      widget.find('[data-ui-field=windspeed_value]').html(windspeed+' mph');
      var rainmm = HG.WebApp.Utility.GetModulePropertyByName(module, 'Sensor.Precipitation.Rain').Value;
      rainmm=rainmm/25.4;
      rainmm = precision(rainmm, 2);
      if (rainmm == '0.00')
       { rainmm = "" ; }
      else
       { widget.find('[data-ui-field=rainmm_value]').html('<img src="pages/control/widgets/homegenie/environment/weather/images/weather-rainy.png" style="margin-left:10px;vertical-align:middle" class="auto-invert" /> ' +rainmm+' in'); };
      // added snow
      var snowmm = HG.WebApp.Utility.GetModulePropertyByName(module, 'Sensor.Precipitation.Snow').Value;
      snowmm=snowmm/25.4;
      snowmm = precision(snowmm, 2); 
      if (snowmm == '0.00')
       { snowmm = ""; }
      else 
       { widget.find('[data-ui-field=snowmm_value]').html('Snow '+snowmm+' in'); };
      // end added snow
      var sunrise = HG.WebApp.Utility.GetModulePropertyByName(module, 'Astronomy.Sunrise').Value;
      widget.find('[data-ui-field=sunrise_value]').html(sunrise);
      var sunset = HG.WebApp.Utility.GetModulePropertyByName(module, 'Astronomy.Sunset').Value;
      widget.find('[data-ui-field=sunset_value]').html(sunset);
      //
      var iconurl = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.IconUrl').Value;
      widget.find('[data-ui-field=icon]').attr('src', this.GetIconUrl(iconurl));
      //
      var icontext = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Description').Value;
      // convert icon text to Title Text, so "clear sky" displays as "Clear Sky"
      icontext = toTitleCase(icontext);
      widget.find('[data-ui-field=description]').html(icontext);
      //
      var last_updated = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.LastUpdated').Value;
      widget.find('[data-ui-field=last_updated_value]').html(last_updated);

      // F and C icons = &#8451; is for C, &#8457; is for F
      // Determine which one to use based on param setting
      var temp_icon = "&#8451;";
      var enable_Fahrenheit = HG.WebApp.Utility.GetModulePropertyByName(module, 'ConfigureOptions.FahrenheitEnable').Value;
      if (enable_Fahrenheit == '1')
       temp_icon = "&#8457;"
      widget.find('[data-ui-field=temp_icon_value]').html(temp_icon);

      // Determine if temperatures should be truncated to whole numbers or use 2 decimal places
      var temp_round = HG.WebApp.Utility.GetModulePropertyByName(module, 'ConfigureOptions.TempRoundEnable').Value;
      if (temp_round == "1")
        { temp_round = 0; }
       else
        { temp_round = 2};
      widget.find('[data-ui-field=temp_round_value]').html(temp_round);
      
      // Get Forecast times for Morning, Afternoon and Evening
      var forecast_morn = HG.WebApp.Utility.GetModulePropertyByName(module, 'ConfigureOptions.Morning').Value;
      widget.find('[data-ui-field=forecast_morn_value]').html(forecast_morn + "am");
      var forecast_aft = HG.WebApp.Utility.GetModulePropertyByName(module, 'ConfigureOptions.Afternoon').Value;
      if (forecast_aft == "12")
        {forecast_aft = "Noon";}
      else
        {forecast_aft = forecast_aft + "pm"}
      widget.find('[data-ui-field=forecast_aft_value]').html(forecast_aft);
      var forecast_eve = HG.WebApp.Utility.GetModulePropertyByName(module, 'ConfigureOptions.Evening').Value;
      widget.find('[data-ui-field=forecast_eve_value]').html(forecast_eve - 12 + "pm");
      
      // temperature is used by the main HG Display and expects it to be in Celcius as it is then converted
      //  based on user HG Preference.  So make sure temperature is in Celcius and use the new variable
      //  temperature_widget to display the current temperature for the widget.
      var temperature_widget = HG.WebApp.Utility.GetModulePropertyByName(module, 'Sensor.Temperature_Widget').Value;
      temperature_widget = Math.round(temperature_widget, temp_round);
      widget.find('[data-ui-field=temperature_widget_value]').html(temperature_widget + temp_icon);      

      // If user has chosen Fahrenheit then do not convert temp related fields
      var feels_like = HG.WebApp.Utility.GetModulePropertyByName(module, 'Sensor.Temperature.FeelsLike').Value;
      if (enable_Fahrenheit == '0')
        feels_like = parseFloat(HG.WebApp.Utility.GetLocaleTemperature(parseFloat(feels_like.replace(',','.'))));
      feels_like = Math.round(feels_like, temp_round);
      widget.find('[data-ui-field=feels_like_value]').html(feels_like + temp_icon);
      // also for Max Temperature
      var temp_max = HG.WebApp.Utility.GetModulePropertyByName(module, 'Sensor.Temperature.Max').Value;
      if (enable_Fahrenheit == '0')
        temp_max = parseFloat(HG.WebApp.Utility.GetLocaleTemperature(parseFloat(temp_max.replace(',','.'))));
      temp_max = Math.round(temp_max, temp_round);
      widget.find('[data-ui-field=temp_max_value]').html(temp_max + temp_icon);
      // also for Min Temperature
      var temp_min = HG.WebApp.Utility.GetModulePropertyByName(module, 'Sensor.Temperature.Min').Value;
      if (enable_Fahrenheit == '0')
        temp_min = parseFloat(HG.WebApp.Utility.GetLocaleTemperature(parseFloat(temp_min.replace(',','.'))));
      temp_min = Math.round(temp_min, temp_round);
      widget.find('[data-ui-field=temp_min_value]').html(temp_min + temp_icon);
      
      // humidity
      var humidity = HG.WebApp.Utility.GetModulePropertyByName(module, 'Sensor.Humidity').Value;
      widget.find('[data-ui-field=humidity_value]').html(humidity + '%');
      
      // Forecast data
      for (var f = 1; f <= 9; f++)
      {
        var fIconUrl = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.IconUrl').Value;
        widget.find('[data-ui-field=forecast_' + f + '_icon]').attr('src', this.GetIconUrl(fIconUrl));
        var fDescription = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.Description').Value;
        widget.find('[data-ui-field=forecast_' + f + '_desc]').html(fDescription);

        var Humidity = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.Humidity').Value;
        if (enable_Fahrenheit == '0')
          humidity = parseFloat(HG.WebApp.Utility.GetLocaleTemperature(parseFloat(Humidity.replace(',','.'))));
 
        var temperatureMax = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.Temperature.Max').Value;
        if (enable_Fahrenheit == '0')
          temperatureMax = parseFloat(HG.WebApp.Utility.GetLocaleTemperature(parseFloat(temperatureMax.replace(',','.'))));
        temperatureMax = Math.round(temperatureMax, temp_round);
 
        var temperatureMin = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.Temperature.Min').Value;
        if (enable_Fahrenheit == '0')
          temperatureMin = parseFloat(HG.WebApp.Utility.GetLocaleTemperature(parseFloat(temperatureMin.replace(',','.'))));
        temperatureMin = Math.round(temperatureMin, temp_round);

        var feels_like = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.Temperature.FeelsLike').Value;
        if (enable_Fahrenheit == '0')
          feels_like = parseFloat(HG.WebApp.Utility.GetLocaleTemperature(parseFloat(feels_like.replace(',','.'))));
        feels_like = Math.round(feels_like, temp_round);
        
		var day_last_updated = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.Temperature.LastUpdated').Value;
        widget.find('[data-ui-field=forecast_' + f + '_humidity]').html(Humidity + '%');
        widget.find('[data-ui-field=forecast_' + f + '_tmin]').html(temperatureMin + temp_icon);
        widget.find('[data-ui-field=forecast_' + f + '_tmax]').html(temperatureMax + temp_icon);
        widget.find('[data-ui-field=forecast_' + f + '_feels_like]').html(feels_like + temp_icon);
        widget.find('[data-ui-field=forecast_' + f + '_day_lu]').html(day_last_updated);

        var displayDate = HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.Weekday').Value.substr(0, 3) + ', ';
        displayDate += HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.Month').Value + ' ';
        displayDate += HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.' + f + '.Day').Value;
        widget.find('[data-ui-field=forecast_' + f + '_date]').html(displayDate);
      }
    }
   // if we should not show day 1 (day 1 = first day monring) then update visibility here
   if (HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.1.Weekday').Value == "")
    {
      document.getElementById('firstDayMorn').style.visibility="hidden";
      document.getElementById('firstDayMornImg').style.visibility="hidden";
      document.getElementById('firstDayMornData').style.visibility="hidden";
    }
   // if we should not show day 4 (day 4 = first day afternoon) then update visibility here
   if (HG.WebApp.Utility.GetModulePropertyByName(module, 'Conditions.Forecast.4.Weekday').Value == "")
    {
      document.getElementById('firstDayAft').style.visibility="hidden";
      document.getElementById('firstDayAftImg').style.visibility="hidden";
      document.getElementById('firstDayAftData').style.visibility="hidden";
    }    
  },

  GetIconUrl: function(icon) {
    return 'pages/control/widgets/homegenie/environment/weather/images/'+icon+".png";
  }
}]